@@ -13,7 +13,7 @@ class ExecImport:
 
     def from_excel(self, sheet='Sheet1', axis=0, index_col=None,
                    orient='records', empty=False, nana=None, **kwargs) -> iter:
-        return ExecExcel(self.path).read(sheet, axis, index_col, **kwargs).to_data(orient, empty, nana)
+        return ExecExcel(self.path).read(sheet, axis, index_col, **kwargs).extract_data(orient, empty, nana)
 
 
 class ExecExport:
